// *** SciGui work figure handling
// *** by G. Casonato - Marzo 2007

function loadFigure(fd, hfig_wk)
  disp('Load Main Figure...');
  
  // legge dati da file
  str = mgetl(fd, 1); // figure
  if strindex(str, '[') == [] then
    // multi-line declaration (new format - >1.0)
    str = mgetl(fd, 1); // tag
    pos = strindex(str, '''Tag'', ''');
    str1 = strsplit(str, pos+7);
    str2 = sscanf(str1(2), '%s');
    str3 = strsplit(str2, length(str2)-2);
    objtag = str3(1);

    str = mgetl(fd, 1); // background color RGB
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [bg_r, bg_g, bg_b] = sscanf(str1(2), '%g %g %g]');

    str = mgetl(fd, 1); // position
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');

  else
    // single-line declaraton (old format - 1.0)
    objtag = 'myGui'; // hardcoded tag
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');
    bg = name2rgb('gray')/255; // hardcoded BG color
    bg_r = bg(1);
    bg_g = bg(2);
    bg_b = bg(3);
  end
  
  // aggiorna finestra
  set(hfig_wk, 'Tag', objtag);
  set(hfig_wk, 'Position', [px py wd hg]);
  set(hfig_wk, 'BackgroundColor', [bg_r, bg_g, bg_b]);
endfunction

function saveFigure (fd, hfig_wk)
  disp('Save Figure...');
  
  tag = get(hfig_wk, 'Tag');
  pos = get(hfig_wk, 'Position');
  pos = evstr(pos);
  bg = get(hfig_wk, 'BackgroundColor');
  bg = evstr(bg);
  mfprintf(fd, '// MAIN GUI\n');
  mfprintf(fd, 'hfig = figure(1, ...\n');
  mfprintf(fd, '  ''Tag'', ''%s'', ...\n', tag);
  mfprintf(fd, '  ''BackgroundColor'', [%g %g %g], ...\n', bg(1), bg(2), bg(3));
  mfprintf(fd, '  ''Position'', [%d %d %d %d]);\n\n', pos(1), pos(2), pos(3), pos(4));
endfunction

function hfig_wk = editFigure (hmode, hfig, hfig_wk)
  disp('Edit Figure...');

  global hgr;

  // hmode definisce modalit:
  // - new:  crea nuova oggetto con ID <hobj>
  // - edit: modifica oggetto esistente <hobj>

  if hmode == 'edit' then
    // edit: legge valori correnti
    objpos = get(hfig_wk, 'Position');
    wd_orig = objpos(3);
    hg_orig = objpos(4);
    objbg = get(hfig_wk, 'BackgroundColor');

    objbg = rgb2name(objbg*255);

     // legge posizione/bg color
    lbl = ['position (x, y): '; ...
           'size (width, height): '; ...
           'BG color name: '];
    def = [string(objpos(1))+' '+string(objpos(2)); ...
           string(objpos(3))+' '+string(objpos(4)); ...
           objbg(1)];
    objdata = x_mdialog('enter object data', lbl, def);
    objpos = evstr(objdata(1 : 2));
    px = objpos(1,1);
    py = objpos(1,2);
    wd = objpos(2,1);
    hg = objpos(2,2);
    objbg = name2rgb(objdata(3))/255;
    bg_r = objbg(1);
    bg_g = objbg(2);
    bg_b = objbg(3);

    // modifica parametri oggetto   
    set(hfig_wk, 'Position', [px py wd hg]);
    set(hfig_wk, 'BackgroundColor', [bg_r, bg_g, bg_b]);

    // ridisegna la griglia, se attiva e se sono cambiate le dimensioni
    if ((wd <> wd_orig) | (hg <> hg_orig)) & (get(hgr(1), 'Parent') > 1) then
      showGrid(hfig_wk);
      drawGrid(hfig_wk);
    end
  else
    // new: imposta valori di default
    objpos = [100 170 400 300];
    px = objpos(1);
    py = objpos(2);
    wd = objpos(3);
    hg = objpos(4);
    objbg = name2rgb('gray')/255;
    bg_r = objbg(1);
    bg_g = objbg(2);
    bg_b = objbg(3);

    // crea finestra di lavoro con le dimensioni specificate
    hfig_wk = figure(hfig_wk, ...
      'Tag', 'myGui', ...
      'Position', [px py wd hg], ...
      'BackgroundColor', [bg_r bg_g bg_b]);
      
    // disegna griglia
    drawGrid(hfig_wk);
  end
  
endfunction

function resetFigure (hfig_wk)
  disp('Reset Figure...');
  
  global hgr;
  
  // elimina griglia
  if get(hgr(1), 'Parent') > 1 then
    showGrid(hfig_wk);
  end  
endfunction

function showGrid (hfig_wk);
  disp('Show Grid...');

  global hgr;

  if get(hgr(1), 'Parent') == 1 then
    disp('enabling grid...');
    doRemove = %F;
  else
    disp('disabling grid...');
    doRemove = %T;
  end

  // attiva/disattiva griglia
  for i = 1 : size(hgr, 1)
    if doRemove == %T  then
      // rimuovi griglia
      hpar = 1;        
    else
      // disegna griglia
      hpar = hfig_wk;
    end 
    set(hgr(i), 'Parent', hpar);    
  end
endfunction

function drawGrid(hfig_wk)
  global hgr;
  hgr = [];

  fbgcol = get(hfig_wk, 'BackgroundColor');

  // disegna griglia 
//  grcol = name2rgb('black')/255;
  if fbgcol == name2rgb('black')/255 then
    grcol = name2rgb('lightgray')/255;
  else
    grcol = name2rgb('black')/255;
  end
  if fbgcol == name2rgb('lightgray')/255 then
    bgcol = name2rgb('black')/255;
  else
    bgcol = name2rgb('lightgray')/255;
  end
  pos = get(hfig_wk, 'Position');
  wd = pos(3);
  hg = pos(4);
  
  // righe
  sty = 50;
  for y = sty : sty : hg
    h = uicontrol(hfig_wk, 'Style', 'text', ...
      'Tag', 'GridLblY'+string(y), ...
      'Horizontalalignment', 'left', ...
      'ForegroundColor ', grcol, ...
      'BackgroundColor ', bgcol, ...
      'FontSize', 8, ...
      'String', string(y), ...
      'Position', [0 y 20 10]); 
    hgr = [hgr; [h]];
    h = uicontrol(hfig_wk, 'Style', 'pushbutton', ...
      'Tag', 'GridRowY'+string(y), ...
      'BackgroundColor ', grcol, ...
      'Position', [20 y+5 wd-25 1]); 
    hgr = [hgr; [h]];
  end

  // colonne
  stx = 50;
  for x = stx : stx : wd
    h = uicontrol(hfig_wk, 'Style', 'text', ...
      'Tag', 'GridLblX'+string(x), ...
      'Horizontalalignment', 'left', ...
      'ForegroundColor ', grcol, ...
      'BackgroundColor ', bgcol, ...
      'FontSize', 8, ...
      'String', string(x), ...
      'Position', [x 0 20 10]); 
    hgr = [hgr; [h]];
    h = uicontrol(hfig_wk, 'Style', 'pushbutton', ...
      'Tag', 'GridRowX'+string(x), ...
      'BackgroundColor ', grcol, ...
      'Position', [x+5 15 1 hg-25]); 
    hgr = [hgr; [h]];
  end
endfunction

