// *** SciGui frame object handling
// *** by G. Casonato - Marzo 2007

function hobj = loadFrame(fd, hfig_wk)
  disp('Load Frame...');
  
  // legge dati da file
  str = mgetl(fd, 1); // uicontrol
  
  // tag
  str = mgetl(fd, 1); 
  pos = strindex(str, '''Tag'', ''');
  str1 = strsplit(str, pos+7);
  str2 = sscanf(str1(2), '%s');
  str3 = strsplit(str2, length(str2)-2);
  objtag = str3(1);
  str = mgetl(fd, 1); 

  // BackgroundColor
  if strindex(str, '''BackgroundColor'', [') == [] then
    bg = name2rgb('gray')/255; // hardcoded BG color
    bg_r = bg(1);
    bg_g = bg(2);
    bg_b = bg(3);
  else
//    pos = strindex(str, '''BackgroundColor'', [');
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [bg_r, bg_g, bg_b] = sscanf(str1(2), '%g %g %g]');
    str = mgetl(fd, 1); 
  end

  // position (MUST BE THE LAST)
//  str = mgetl(fd, 1); 
  pos = strindex(str, '[');
  str1 = strsplit(str, pos);
  [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');

  // crea oggetto
  hobj = uicontrol(hfig_wk, 'Style', 'frame', ...
    'Tag', objtag, ...
    'BackgroundColor', [bg_r, bg_g, bg_b], ...
    'Position', [px py wd hg]);

endfunction

function saveFrame (fd, hobj)
  disp('Save Frame...');

  pos = get(hobj, 'Position');
  pos = evstr(pos);
  tag = get(hobj, 'Tag');
  bg = get(hobj, 'BackgroundColor');
  bg = evstr(bg);

  mfprintf(fd, '// FRAME: %s\n', tag);
  mfprintf(fd, 'hobj = uicontrol(hfig, ''Style'', ''frame'', ...\n');
  mfprintf(fd, '  ''Tag'', ''%s'', ...\n', tag);
  mfprintf(fd, '  ''BackgroundColor'', [%g %g %g], ...\n', bg(1), bg(2), bg(3));
  mfprintf(fd, '  ''Position'', [%d %d %d %d]);\n\n', pos(1), pos(2), pos(3), pos(4)); 
endfunction

function hobj = editFrame (hmode, hfig_wk, hobj)
  disp('Edit Frame...');

  // hmode definisce modalit:
  // - new:  crea nuova oggetto con ID <hobj>
  // - edit: modifica oggetto esistente <hobj>

  if hmode == 'edit' then
    // edit: legge valori correnti
    objpos = get(hobj, 'Position');
    objbg = get(hobj, 'BackgroundColor');
    objbg = evstr(objbg);
  else
    // new: imposta valori di default
    objpos = [100 50 150 120];
    objtag = 'Frame'+string(hobj);
    objbg = name2rgb('gray')/255;
  end  
  
  objbg = rgb2name(objbg*255);

  // legge posizione
  lbl = ['Position (x, y): '; ...
         'Size (width, height): '; ...
         'BG color name: '];
  def = [string(objpos(1))+' '+string(objpos(2)); ...
         string(objpos(3))+' '+string(objpos(4)); ...
         objbg(1)];
 
  objdata = x_mdialog('enter object data', lbl, def);
  objpos = evstr(objdata(1 : 2));
  objbg = name2rgb(objdata(3))/255;

  px = objpos(1,1);
  py = objpos(1,2);
  wd = objpos(2,1);
  hg = objpos(2,2);
  
  bg_r = objbg(1);
  bg_g = objbg(2);
  bg_b = objbg(3);

  if hmode == 'edit' then
    // edit: modifica parametri oggetto   
    set(hobj, 'Position', [px py wd hg]);
    set(hobj, 'BackgroundColor', [bg_r, bg_g, bg_b]);
  else
    // new: aggiunge oggetto nella posizione specificata
    hobj = uicontrol(hfig_wk, 'Style', 'frame', ...
      'Tag', string(objtag), ...
      'BackgroundColor', [bg_r, bg_g, bg_b], ...
      'Position', [px py wd hg]);
  end
endfunction


