// *** SciGui slider object handling
// *** by G. Casonato - Aprile 2007

function hobj = loadSlider (fd, hfig_wk)
  disp('Load Slider ...');
  
  // legge dati da file
  str = mgetl(fd, 1); // uicontrol
  
  // tag
  str = mgetl(fd, 1); 
  pos = strindex(str, '''Tag'', ''');
  str1 = strsplit(str, pos+7);
  str2 = sscanf(str1(2), '%s');
  str3 = strsplit(str2, length(str2)-2);
  objtag = str3(1);
  str = mgetl(fd, 1);
  
  // string
  pos = strindex(str, '''String'', ''');
  str1 = strsplit(str, pos+10);
  str2 = sscanf(str1(2), '%s');
  str3 = strsplit(str2, length(str2)-2);
  objstr = str3(1);
  str = mgetl(fd, 1); 
  
  // Min
  pos = strindex(str, '''Min'', ');
  str1 = strsplit(str, pos+6);
  str2 = sscanf(str1(2), '%s');
  objmin = evstr(str2);
  str = mgetl(fd, 1); 
  
  // Max
  pos = strindex(str, '''Max'', ');
  str1 = strsplit(str, pos+6);
  str2 = sscanf(str1(2), '%s');
  objmax = evstr(str2);
  str = mgetl(fd, 1); 
  
  // position
  pos = strindex(str, '[');
  str1 = strsplit(str, pos);
  [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');

  // crea oggetto
  hobj = uicontrol(hfig_wk, 'Style', 'slider', ...
    'Tag', objtag, ...
    'String', objstr, ...
    'Min', objmin, ...
    'Max', objmax, ...
    'Position', [px py wd hg]);
endfunction

function saveSlider (fd, hobj)
  disp('Save Slider ...');

  tag = get(hobj, 'Tag');
  pos = get(hobj, 'Position');
  pos = evstr(pos);
  str = get(hobj, 'String');
  slmin = get(hobj, 'Min');
  slmax = get(hobj, 'Max');
  mfprintf(fd, '// SLIDER: %s\n', tag);
  mfprintf(fd, 'hobj = uicontrol(hfig, ''Style'', ''slider'', ...\n');
  mfprintf(fd, '  ''Tag'', ''%s'', ...\n', tag);
  mfprintf(fd, '  ''String'', ''%s'', ...\n', str);
  mfprintf(fd, '  ''Min'', %d, ...\n', slmin);
  mfprintf(fd, '  ''Max'', %d, ...\n', slmax);
  mfprintf(fd, '  ''Position'', [%d %d %d %d]);\n\n', pos(1), pos(2), pos(3), pos(4)); 
endfunction

function hobj = editSlider (hmode, hfig_wk, hobj)
  disp('Edit Slider ...');

  // hmode definisce modalit:
  // - new:  crea nuova oggetto con ID <hobj>
  // - edit: modifica oggetto esistente <hobj>

  // legge posizione/nome
  if hmode == 'edit' then
    // edit: legge valori correnti
    objpos = get(hobj, 'Position');
    objstr = get(hobj, 'String');
    objmin = get(hobj, 'Min');
    objmax = get(hobj, 'Max');
  else
    // new: imposta valori di default
    objpos = [100 50 100 20];
    objtag = 'Slider'+string(hobj);
    objstr = objtag;
    objmin = 0;
    objmax = 10;
  end  
  
  // legge valori parametri
  lbl = ['Position (x, y): '; ...
         'Size (width, height): '; ...
         'Min: '; ...
         'Max: '];
  def = [string(objpos(1))+' '+string(objpos(2)); ...
         string(objpos(3))+' '+string(objpos(4)); ...
         string(objmin); ...
         string(objmax)];
  objdata = x_mdialog('enter object data', lbl, def);
  objpos = evstr(objdata(1 : 2));
  objmin = evstr(objdata(3));
  objmax = evstr(objdata(4));
  
  px = objpos(1,1);
  py = objpos(1,2);
  wd = objpos(2,1);
  hg = objpos(2,2);

  if hmode == 'edit' then
    // edit: modifica parametri oggetto   
    set(hobj, 'Position', [px py wd hg]);
    set(hobj, 'Min', objmin);
    set(hobj, 'Max', objmax);
  else
    // new: aggiunge oggetto nella posizione specificata
    hobj = uicontrol(hfig_wk, 'Style', 'slider', ...
      'Tag', objtag, ...
      'String', objstr, ...
      'Min', objmin, ...
      'Max', objmax, ...
      'Position', [px py wd hg]);
  end
endfunction


