// *** SciGui textfield object handling
// *** by G. Casonato - Marzo 2007

function hobj = loadTextField(fd, hfig_wk)
  disp('Load TextField...');
  
  // legge dati da file
  str = mgetl(fd, 1); // uicontrol
  str = mgetl(fd, 1); 
  
  // tag
  str = convstr(str, 'l');
  pos = strindex(str, '''tag'', ''');
  str1 = strsplit(str, pos+7);
  str2 = sscanf(str1(2), '%s');
  str3 = strsplit(str2, length(str2)-2);
  objtag = str3(1);
  str = mgetl(fd, 1); 
  
  // string
  str = convstr(str, 'l');
  pos = strindex(str, '''string'', ''');
  str1 = strsplit(str, pos+10);
  str2 = sscanf(str1(2), '%s');
  str3 = strsplit(str2, length(str2)-2);
  objstr = str3(1);
  str = mgetl(fd, 1); 

  // HorizontalAlignment
  if strindex(str, '''HorizontalAlignment'', ''') == [] then
    objhalign = 'left';
  else
    pos = strindex(str, '''HorizontalAlignment'', ''');
    str1 = strsplit(str, pos+23);
    str2 = sscanf(str1(2), '%s');
    str3 = strsplit(str2, length(str2)-2);
    objhalign = str3(1);
    str = mgetl(fd, 1); 
  end

  // FontAngle
  if strindex(str, '''FontAngle'', ''') == [] then
    objfntang = 'normal';
  else
    pos = strindex(str, '''FontAngle'', ''');
    str1 = strsplit(str, pos+13);
    str2 = sscanf(str1(2), '%s');
    str3 = strsplit(str2, length(str2)-2);
    objfntang = str3(1);
    str = mgetl(fd, 1); 
  end

  // FontSize
  if strindex(str, '''FontSize'', ') == [] then
    objfntsz = '12';
  else
    pos = strindex(str, '''FontSize'', ');
    str1 = strsplit(str, pos+10);
    str2 = sscanf(str1(2), '%s');
    objfntsz = evstr(str2);
    str = mgetl(fd, 1); 
  end

  // FontWeight
  if strindex(str, '''FontWeight'', ''') == [] then
    objfntwhg = 'normal';
  else
    pos = strindex(str, '''FontWeight'', ''');
    str1 = strsplit(str, pos+14);
    str2 = sscanf(str1(2), '%s');
    str3 = strsplit(str2, length(str2)-2);
    objfntwhg = str3(1);
    str = mgetl(fd, 1); 
  end

  // BackgroundColor
  if strindex(str, '''BackgroundColor'', [') == [] then
    bg = name2rgb('gray')/255; // hardcoded BG color
    bg_r = bg(1);
    bg_g = bg(2);
    bg_b = bg(3);
  else
//    pos = strindex(str, '''BackgroundColor'', [');
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [bg_r, bg_g, bg_b] = sscanf(str1(2), '%g %g %g]');
    str = mgetl(fd, 1); 
  end

  // ForegroundColor
  if strindex(str, '''ForegroundColor'', [') == [] then
    fg = name2rgb('black')/255; // hardcoded FG color
    fg_r = fg(1);
    fg_g = fg(2);
    fg_b = fg(3);
  else
//    pos = strindex(str, '''ForegroundColor'', [');
    pos = strindex(str, '[');
    str1 = strsplit(str, pos);
    [fg_r, fg_g, fg_b] = sscanf(str1(2), '%g %g %g]');
    str = mgetl(fd, 1); 
  end

  // position (MUST BE THE LAST)
//  str = mgetl(fd, 1); 
  pos = strindex(str, '[');
  str1 = strsplit(str, pos);
  [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');

  // crea oggetto
  hobj = uicontrol(hfig_wk, 'Style', 'edit', ...
    'Tag', objtag, ...
    'String', objstr, ...
    'HorizontalAlignment', objhalign, ...
    'FontAngle', objfntang, ...
    'FontSize', objfntsz, ...
    'FontWeight', objfntwhg, ...
    'BackgroundColor', [bg_r, bg_g, bg_b], ...
    'ForegroundColor', [fg_r, fg_g, fg_b], ...
    'Position', [px py wd hg]);
endfunction

function saveTextField (fd, hobj)
  disp('Save TextField...');

  tag = get(hobj, 'Tag');
  pos = get(hobj, 'Position');
  pos = evstr(pos);
  str = get(hobj, 'String');
  halign = get(hobj, 'HorizontalAlignment');
  fntang = get(hobj, 'FontAngle');
  fntsz = get(hobj, 'FontSize');
  fntwhg = get(hobj, 'FontWeight');
  bg = get(hobj, 'BackgroundColor');
  bg = evstr(bg);
  fg = get(hobj, 'ForegroundColor');
  fg = evstr(fg);
  mfprintf(fd, '// TEXTFIELD: %s\n', tag);
  mfprintf(fd, 'hobj = uicontrol(hfig, ''Style'', ''edit'', ...\n');
  mfprintf(fd, '  ''Tag'', ''%s'', ...\n', tag);
  mfprintf(fd, '  ''String'', ''%s'', ...\n', str);
  mfprintf(fd, '  ''HorizontalAlignment'', ''%s'', ...\n', halign);  
  mfprintf(fd, '  ''FontAngle'', ''%s'', ...\n', fntang);  
  mfprintf(fd, '  ''FontSize'', %d, ...\n', fntsz);  
  mfprintf(fd, '  ''FontWeight'', ''%s'', ...\n', fntwhg);  
  mfprintf(fd, '  ''BackgroundColor'', [%g %g %g], ...\n', bg(1), bg(2), bg(3));
  mfprintf(fd, '  ''ForegroundColor'', [%g %g %g], ...\n', fg(1), fg(2), fg(3));
  mfprintf(fd, '  ''Position'', [%d %d %d %d]);\n\n', pos(1), pos(2), pos(3), pos(4)); 
endfunction

function hobj = editTextField (hmode, hfig_wk, hobj)
  disp('Edit TextField...');

  // hmode definisce modalit:
  // - new:  crea nuova oggetto con ID <hobj>
  // - edit: modifica oggetto esistente <hobj>

  if hmode == 'edit' then
    // edit: legge valori correnti
    objpos = get(hobj, 'Position');
    objstr = get(hobj, 'String');
    objhalign = get(hobj, 'HorizontalAlignment');
    objfntang = get(hobj, 'FontAngle');
    objfntsz = get(hobj, 'FontSize');
    objfntwhg = get(hobj, 'FontWeight');
    objbg = get(hobj, 'BackgroundColor');
    objbg = evstr(objbg);
    objfg = get(hobj, 'ForegroundColor');
    objfg = evstr(objfg);
  else
    // new: imposta valori di default
    objpos = [100 100 50 20];
    objtag = 'TextField'+string(hobj);
    objstr = objtag;
    objhalign = 'center';
    objfntang = 'normal';
    objfntsz = 12;
    objfntwhg = 'normal';
    objbg = name2rgb('gray')/255;
    objfg = name2rgb('black')/255;
  end  

  objbg = rgb2name(objbg*255);
  objfg = rgb2name(objfg*255);

  // legge posizione/valore
  lbl = ['Position (x, y): '; ...
         'Size (width, height): '; ...
         'Horiz alignment (left | center | right): '; ...
         'Font angle (normal | italic | oblique): '; ...
         'Font size: '; ...
         'Font weight (light | normal | demi | bold): '; ...
         'BG color name: '; ...
         'FG color name: '; ...
         'Value: '];

  def = [string(objpos(1))+' '+string(objpos(2)); ...
         string(objpos(3))+' '+string(objpos(4)); ...
         objhalign; ...
         objfntang; ...
         string(objfntsz); ...
         objfntwhg; ...
         objbg(1); ...
         objfg(1); ...
         objstr];

  objdata = x_mdialog('enter object data', lbl, def);
  objpos = evstr(objdata(1 : 2));
  objhalign = objdata(3);
  objfntang = objdata(4);
  objfntsz = objdata(5);
  objfntwhg = objdata(6);
  objbg = name2rgb(objdata(7))/255;
  objfg = name2rgb(objdata(8))/255;
  objstr = objdata(9);

  px = objpos(1,1);
  py = objpos(1,2);
  wd = objpos(2,1);
  hg = objpos(2,2);

  bg_r = objbg(1);
  bg_g = objbg(2);
  bg_b = objbg(3);

  fg_r = objfg(1);
  fg_g = objfg(2);
  fg_b = objfg(3);

  // applica parametri
  if hmode == 'edit' then
    // edit: modifica parametri oggetto   
    set(hobj, 'Position', [px py wd hg]);
    set(hobj, 'String', objstr);
    set(hobj, 'Horizontalalignment', objhalign);
    set(hobj, 'FontAngle', objfntang);
    set(hobj, 'FontSize', objfntsz);
    set(hobj, 'FontWeight', objfntwhg);
    set(hobj, 'BackgroundColor', [bg_r, bg_g, bg_b]);
    set(hobj, 'ForegroundColor', [fg_r, fg_g, fg_b]);
  else
    // new: aggiunge oggetto nella posizione specificata
    hobj = uicontrol(hfig_wk, 'style', 'edit', ...
      'Tag', string(objtag), ...
      'String', string(objstr), ...
      'Horizontalalignment', objhalign, ...
      'FontAngle', objfntang, ...
      'FontSize', objfntsz, ...
      'FontWeight', objfntwhg, ...
      'BackgroundColor', [bg_r, bg_g, bg_b], ...
      'ForegroundColor', [fg_r, fg_g, fg_b], ...
      'Position', [px py wd hg]);
    disp(hobj);
  end
endfunction

